@@ -24,48 +24,48 @@
 #'
 #' @examples
 #' \dontrun{
-#' library(jmvReadWrite);
-#' dtaInp <- bfi_sample2;
-#' nmeInp <- paste0(tempfile(), "_", 1:3, ".rds");
-#' nmeOut <- paste0(tempfile(), ".omv");
-#' for (i in seq_along(nmeInp)) saveRDS(dtaInp[-i - 1], nmeInp[i]);
+#' library(jmvReadWrite)
+#' dtaInp <- bfi_sample2
+#' nmeInp <- paste0(tempfile(), "_", 1:3, ".rds")
+#' nmeOut <- paste0(tempfile(), ".omv")
+#' for (i in seq_along(nmeInp)) saveRDS(dtaInp[-i - 1], nmeInp[i])
 #' # save dtaInp three times (i.e., the length of nmeInp), removing one data columns in
 #' # each data set (for demonstration purposes, A1 in the first, A2 in the second, ...)
-#' merge_rows_omv(fleInp = nmeInp, fleOut = nmeOut, colInd = TRUE);
-#' cat(file.info(nmeOut)$size);
+#' merge_rows_omv(fleInp = nmeInp, fleOut = nmeOut, colInd = TRUE)
+#' cat(file.info(nmeOut)$size)
 #' # -> 10767 (size may differ on different OSes)
-#' dtaOut <- read_omv(nmeOut, sveAtt = FALSE);
+#' dtaOut <- read_omv(nmeOut, sveAtt = FALSE)
 #' # read the data set where the three original datasets were added as rows and show
 #' # the variable names
-#' cat(names(dtaInp));
-#' cat(names(dtaOut));
+#' cat(names(dtaInp))
+#' cat(names(dtaOut))
 #' # compared to the input data set, we have the same variable names; fleInd (switched
 #' # on by colInd = TRUE and showing from which data set the rows are coming from) is
 #' # new and A1 is moved to the end of the list (the "original" order of variables may
 #' # not always be preserved and columns missing from at least one of the input data
 #' # sets may be added at the end)
-#' cat(dim(dtaInp), dim(dtaOut));
+#' cat(dim(dtaInp), dim(dtaOut))
 #' # the first dimension of the data sets (rows) is now three times of that of the input
 #' # data set (250 -> 750), the second dimension (columns / variables) is increased by 1
 #' # (for "fleInd")
 #'
-#' merge_rows_omv(fleInp = nmeInp, fleOut = nmeOut, typMrg = "common");
+#' merge_rows_omv(fleInp = nmeInp, fleOut = nmeOut, typMrg = "common")
 #' # the argument typMrg = "common" removes the columns that are not present in all of
 #' # the input data sets (i.e., A1, A2, A3)
-#' dtaOut <- read_omv(nmeOut, sveAtt = FALSE);
+#' dtaOut <- read_omv(nmeOut, sveAtt = FALSE)
 #' # read the data set where the three original datasets were added as rows and show
 #' # the variable names
-#' cat(names(dtaInp));
-#' cat(names(dtaOut));
+#' cat(names(dtaInp))
+#' cat(names(dtaOut))
 #' # compared to the input data set, the variables that were missing in at least one
 #' # data set (i.e., "A1", "A2" and "A3") are removed
-#' cat(dim(dtaInp), dim(dtaOut));
+#' cat(dim(dtaInp), dim(dtaOut))
 #' # the first dimension of the data sets (rows) is now three times of that of the
 #' # input data set (250 -> 750), the second dimension (columns / variables) is
 #' # reduced by 3 (i.e., "A1", "A2", "A3")
 #'
-#' unlink(nmeInp);
-#' unlink(nmeOut);
+#' unlink(nmeInp)
+#' unlink(nmeOut)
 #' }
 #'
 #' @export merge_rows_omv
@@ -73,67 +73,67 @@
 merge_rows_omv <- function(fleInp = c(), fleOut = "", typMrg = c("all", "common"), colInd = FALSE, rstRwN = TRUE, rmvDpl = FALSE, varSrt = c(), usePkg = c("foreign", "haven"), selSet = "", ...) {
 
     # check and format input file names and handle / check further input arguments
-    fleInp <- fmtFlI(fleInp, minLng = 2);
-    typMrg <- match.arg(typMrg);
-    usePkg <- match.arg(usePkg);
-    varArg <- list(...);
+    fleInp <- fmtFlI(fleInp, minLng = 2)
+    typMrg <- match.arg(typMrg)
+    usePkg <- match.arg(usePkg)
+    varArg <- list(...)
 
     # read files
-    dtaInp <- vector(mode = "list", length = length(fleInp));
+    dtaInp <- vector(mode = "list", length = length(fleInp))
     for (i in seq_along(fleInp)) {
-        dtaInp[[i]] <- addInd(read_all(fleInp[i], usePkg, selSet, varArg), ifelse(colInd, fleInp[i], ""));
+        dtaInp[[i]] <- addInd(read_all(fleInp[i], usePkg, selSet, varArg), ifelse(colInd, fleInp[i], ""))
     }
 
     # merge files - the additional arguments are the same in either case
-    crrArg <- adjArg(c("rbind", "data.frame"), list(), varArg, c());
+    crrArg <- adjArg(c("rbind", "data.frame"), list(), varArg, c())
     # keeping all existing variables, filling the void columns with NA
     if      (typMrg == "all") {
         # determine the variable names in all input data sets and remove duplicates
         # (order ensures that the data set that contains most variables is prioritized,
         # but yet, it is still impossible to preserve the whole order - i.e., variables
         # missing in one data set may end up at the end)
-        varNme <- unlist(sapply(dtaInp[order(-sapply(sapply(dtaInp, dim, simplify = FALSE), "[[", 2))], names, simplify = FALSE));
-        varNme <- varNme[!duplicated(varNme)];
-        dtaOut <- addCol(dtaInp[[1]], varNme);
+        varNme <- unlist(sapply(dtaInp[order(-sapply(sapply(dtaInp, dim, simplify = FALSE), "[[", 2))], names, simplify = FALSE))
+        varNme <- varNme[!duplicated(varNme)]
+        dtaOut <- addCol(dtaInp[[1]], varNme)
         for (i in setdiff(seq_along(fleInp), 1)) {
-            dtaOut <- do.call(rbind, c(list(dtaOut, addCol(dtaInp[[i]], varNme)), crrArg));
+            dtaOut <- do.call(rbind, c(list(dtaOut, addCol(dtaInp[[i]], varNme)), crrArg))
         }
     # keeping only variables that are common to all input data sets
     } else if (typMrg == "common") {
-        varNme <- Reduce(intersect, sapply(dtaInp, names, simplify = FALSE));
+        varNme <- Reduce(intersect, sapply(dtaInp, names, simplify = FALSE))
         if (identical(varNme, character(0))) {
             stop(paste("The data sets in the files that were given as fleInp-argument do not contain variables that are overlapping (i.e., contained in all data sets).",
-                       "You can either reduce the number of data sets given to fleInp or use \"outer\" as argument for \"typMrg\" (see Details in the help for this function)."));
+                       "You can either reduce the number of data sets given to fleInp or use \"outer\" as argument for \"typMrg\" (see Details in the help for this function)."))
         }
-        dtaOut <- dtaInp[[1]][, varNme];
+        dtaOut <- dtaInp[[1]][, varNme]
         for (i in setdiff(seq_along(fleInp), 1)) {
-            dtaOut <- do.call(rbind, c(list(dtaOut, dtaInp[[i]][, varNme]), crrArg));
+            dtaOut <- do.call(rbind, c(list(dtaOut, dtaInp[[i]][, varNme]), crrArg))
         }
     }
 
     # remove row names
     if (rstRwN == TRUE) {
-        rownames(dtaOut) <- NULL;
+        rownames(dtaOut) <- NULL
     }
 
     # remove duplicate rows
     if (rmvDpl == TRUE) {
-        dtaOut <- dtaOut[!duplicated(dtaOut[, setdiff(varNme, "fleInd")]), ];
+        dtaOut <- dtaOut[!duplicated(dtaOut[, setdiff(varNme, "fleInd")]), ]
     }
 
     # sort data frame (if varSrt not empty)
-    dtaOut <- srtFrm(dtaOut, varSrt);
+    dtaOut <- srtFrm(dtaOut, varSrt)
 
     # write files (if fleOut is not empty) or return resulting data frame
     if (nzchar(fleOut)) {
-        write_omv(dtaOut, nrmFle(fleOut));
+        write_omv(dtaOut, nrmFle(fleOut))
     } else {
         dtaOut
     }
 }
 
 addCol <- function(dtaFrm = NULL, varNme = c()) {
-    varDff <- setdiff(varNme, names(dtaFrm));
+    varDff <- setdiff(varNme, names(dtaFrm))
     if (length(varDff) > 0) {
         cbind(dtaFrm, stats::setNames(data.frame(as.list(NA[seq_along(varDff)])), varDff))[, varNme]
     } else {
@@ -145,6 +145,6 @@ addInd <- function(dtaFrm = NULL, fleNme = "") {
     if (fleNme == "") {
         dtaFrm
     } else {
-        cbind(list(fleInd = rep(gsub(paste0(".", tools::file_ext(fleNme)), "", basename(fleNme)), dim(dtaFrm)[1])), dtaFrm);
+        cbind(list(fleInd = rep(gsub(paste0(".", tools::file_ext(fleNme)), "", basename(fleNme)), dim(dtaFrm)[1])), dtaFrm)
     }
 }
